@@ -45,10 +45,11 @@ load_sample (char *samplename)
 		framecount = afGetFrameCount(affd, AF_DEFAULT_TRACK);
 		sample->speed = (int) afGetRate(affd, AF_DEFAULT_TRACK);
 
-		if (channels <= 2) {
+		if (channels <= 2)
 			sample->stereo = (channels == 2);
-		} else
+		else
 			err = -1;
+
 		if (precision == 8)
 			sample->format = AFMT_U8;
 		else if (precision == 16) {
@@ -69,12 +70,14 @@ load_sample (char *samplename)
 			}
 		}
 		afCloseFile(affd);
-	}
+	} else
+		err = -1;
 
 	if (err == -1) {
 		free(sample);
 		return NULL;
 	}
+
 	return sample;
 }
 
