@@ -14,7 +14,7 @@
 
 #include <gtk/gtk.h>
 
-#include "gtkpbinit.h"
+#include "gtkpbbinit.h"
 
 #define POLLTIME		10	/* in miliseconds */
 #define POPTO(to)		((to) * 100 / POLLTIME)
