@@ -53,7 +53,7 @@ session_save (GnomeClient *client, int phase, GnomeSaveStyle save_style,
 	
 	printf ("session_save\n");
 	sm_client = gnome_master_client ();
-	gnome_client_set_clone_command (sm_client, 1, md->argv);
+	gnome_client_set_clone_command (sm_client, md->argc, md->argv);
 	gnome_client_set_restart_command (sm_client, md->argc, md->argv);
 	return TRUE;
 }
