@@ -23,15 +23,12 @@
 #include <glib.h>
 #include <libgnomeui/libgnomeui.h>
 
-typedef struct {
-	int	* argc;
-	char	***argv;
-} GtkPbArgv;
+#include "gtkpbbinit.h"
 
 /* prototypes */
-void session_init (int argc, char *argv[]);
+void session_init (struct init *md);
 void session_die (GnomeClient *client, gpointer user_data);
-gboolean session_save (GnomeClient *client, int phase, GnomeSaveStyle save_style, int end, GnomeInteractStyle interact_style, int fast, gpointer user_data);
+gboolean session_save (GnomeClient *client, int phase, GnomeSaveStyle save_style, int end, GnomeInteractStyle interact_style, int fast, struct init *md);
 
 #endif /* ENABLE_GNOME */
 #endif /* INCLUDE_SESSION_H */
